"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const dom_1 = require("../util/dom");
const object_1 = require("../util/object");
const color_1 = __importDefault(require("./color"));
const font_family_1 = __importDefault(require("./font-family"));
const font_size_1 = __importDefault(require("./font-size"));
const font_weight_1 = __importDefault(require("./font-weight"));
const i18n_1 = __importDefault(require("./i18n"));
const length_1 = __importDefault(require("./length"));
const media_1 = __importDefault(require("./media"));
const opacity_1 = __importDefault(require("./opacity"));
const palette_1 = __importDefault(require("./palette"));
const radius_1 = __importDefault(require("./radius"));
const size_1 = __importDefault(require("./size"));
const transition_1 = __importDefault(require("./transition"));
const vars_1 = __importDefault(require("./vars"));
const z_index_1 = __importDefault(require("./z-index"));
const defaultTheme = {
    $: {
        color: color_1.default,
        fontFamily: font_family_1.default,
        fontSize: font_size_1.default,
        fontWeight: font_weight_1.default,
        i18n: i18n_1.default,
        length: length_1.default,
        media: media_1.default,
        opacity: opacity_1.default,
        palette: {},
        radius: radius_1.default,
        size: size_1.default,
        transition: transition_1.default,
        vars: vars_1.default,
        zIndex: z_index_1.default,
    },
};
const createTheme = (theme = {}, isDarkMode = false) => {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u, _v, _w, _x, _y, _z;
    const result = (0, object_1.merge)(defaultTheme, theme);
    result.$.vars.isDarkMode = isDarkMode;
    result.$.vars.isMobile = dom_1.isMobile;
    result.$.color.dynamic = isDarkMode ? result.$.color.dark : result.$.color.light;
    result.$.color['!dynamic'] = isDarkMode ? result.$.color.light : result.$.color.dark;
    result.$.palette.primary = (0, palette_1.default)((_c = (_b = (_a = theme === null || theme === void 0 ? void 0 : theme.$) === null || _a === void 0 ? void 0 : _a.palette) === null || _b === void 0 ? void 0 : _b.primary) !== null && _c !== void 0 ? _c : result.$.color.blue, result);
    result.$.palette.secondary = (0, palette_1.default)((_f = (_e = (_d = theme === null || theme === void 0 ? void 0 : theme.$) === null || _d === void 0 ? void 0 : _d.palette) === null || _e === void 0 ? void 0 : _e.secondary) !== null && _f !== void 0 ? _f : result.$.color.gray700, result);
    result.$.palette.success = (0, palette_1.default)((_j = (_h = (_g = theme === null || theme === void 0 ? void 0 : theme.$) === null || _g === void 0 ? void 0 : _g.palette) === null || _h === void 0 ? void 0 : _h.success) !== null && _j !== void 0 ? _j : {
        main: result.$.color.green,
        font: result.$.color.light.font,
    }, result);
    result.$.palette.danger = (0, palette_1.default)((_m = (_l = (_k = theme === null || theme === void 0 ? void 0 : theme.$) === null || _k === void 0 ? void 0 : _k.palette) === null || _l === void 0 ? void 0 : _l.danger) !== null && _m !== void 0 ? _m : result.$.color.red, result);
    result.$.palette.warning = (0, palette_1.default)((_q = (_p = (_o = theme === null || theme === void 0 ? void 0 : theme.$) === null || _o === void 0 ? void 0 : _o.palette) === null || _p === void 0 ? void 0 : _p.warning) !== null && _q !== void 0 ? _q : result.$.color.yellow, result);
    result.$.palette.info = (0, palette_1.default)((_t = (_s = (_r = theme === null || theme === void 0 ? void 0 : theme.$) === null || _r === void 0 ? void 0 : _r.palette) === null || _s === void 0 ? void 0 : _s.info) !== null && _t !== void 0 ? _t : result.$.color.cyan, result);
    result.$.palette.light = (0, palette_1.default)((_w = (_v = (_u = theme === null || theme === void 0 ? void 0 : theme.$) === null || _u === void 0 ? void 0 : _u.palette) === null || _v === void 0 ? void 0 : _v.light) !== null && _w !== void 0 ? _w : {
        main: result.$.color.gray100,
        background: result.$.color.white,
    }, result);
    result.$.palette.dark = (0, palette_1.default)((_z = (_y = (_x = theme === null || theme === void 0 ? void 0 : theme.$) === null || _x === void 0 ? void 0 : _x.palette) === null || _y === void 0 ? void 0 : _y.dark) !== null && _z !== void 0 ? _z : result.$.color.gray900, result);
    result.$.palette.dynamic = isDarkMode ? result.$.palette.dark : result.$.palette.light;
    result.$.palette['!dynamic'] = isDarkMode ? result.$.palette.light : result.$.palette.dark;
    return result;
};
exports.default = createTheme;
